==> haskell-req-3.13.1-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-req.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 req
version:              3.13.1
visibility:           public
id:                   req-3.13.1-GcZRAaoKsmt3puD02ncBQi
key:                  req-3.13.1-GcZRAaoKsmt3puD02ncBQi
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/req
synopsis:             HTTP client library
description:          HTTP client library.
category:             Network, Web
abi:                  b28057e1e86a0b80ae2cacc17c48dfdb
exposed:              True
exposed-modules:      Network.HTTP.Req
import-dirs:          /usr/lib/ghc-9.4.8/site-local/req-3.13.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/req-3.13.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/req-3.13.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-req
hs-libraries:         HSreq-3.13.1-GcZRAaoKsmt3puD02ncBQi
depends:
    aeson-2.1.2.1-17AWhWkbfJE926UMi0wPlA
    authenticate-oauth-1.7-J1Etl0BLHvyCxAdP4dTCjZ base-4.17.2.1
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3jbMOlKTiDn4NCqaBZ47Ne containers-0.6.7
    crypton-connection-0.4.1-J0unZqQZrn75537dGdKDbL
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc exceptions-0.10.5
    http-api-data-0.5.1-6UskEvRLFLr314zFYq2DbR
    http-client-0.7.17-7XldJlduiNLIsbgii6IMTa
    http-client-tls-0.3.6.4-3rL8mSedPXPGZlFbvbn6B2
    http-types-0.12.4-6IzIilaA47l58TRShghvhm
    modern-uri-0.3.6.1-CjeEZgkpnxX1PfDqm2ss0K
    monad-control-1.0.3.1-Eri4AwhrtCa8G52kkUFfeD mtl-2.2.2
    retry-0.9.3.1-4KlaHyu6mnzF5UBo1lmEsD template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    transformers-base-0.4.6-9gqoIpeYmGjDLnucKUpqef
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-req/html/req.haddock
haddock-html:         /usr/share/doc/haskell-req/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-req-3.13.1-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-req.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 req
version:              3.13.1
visibility:           public
id:                   req-3.13.1-2ohnkoUYjDcFrBZJ3D2O5r
key:                  req-3.13.1-2ohnkoUYjDcFrBZJ3D2O5r
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/req
synopsis:             HTTP client library
description:          HTTP client library.
category:             Network, Web
abi:                  b64c4c5d9b97fc72b13719e002b860fc
exposed:              True
exposed-modules:      Network.HTTP.Req
import-dirs:          /usr/lib/ghc-9.4.8/site-local/req-3.13.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/req-3.13.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/req-3.13.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-req
hs-libraries:         HSreq-3.13.1-2ohnkoUYjDcFrBZJ3D2O5r
depends:
    aeson-2.1.2.1-17AWhWkbfJE926UMi0wPlA
    authenticate-oauth-1.7-Gn54rIKrlN1BfmfiosteHp base-4.17.2.1
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3jbMOlKTiDn4NCqaBZ47Ne containers-0.6.7
    crypton-connection-0.4.1-J0unZqQZrn75537dGdKDbL
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc exceptions-0.10.5
    http-api-data-0.5.1-6UskEvRLFLr314zFYq2DbR
    http-client-0.7.18-7J2pWtgV41wCh8tO4e8XTa
    http-client-tls-0.3.6.4-JK4I6xiNtggFn7ElWv8VCk
    http-types-0.12.4-6IzIilaA47l58TRShghvhm
    modern-uri-0.3.6.1-CjeEZgkpnxX1PfDqm2ss0K
    monad-control-1.0.3.1-Eri4AwhrtCa8G52kkUFfeD mtl-2.2.2
    retry-0.9.3.1-4KlaHyu6mnzF5UBo1lmEsD template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    transformers-base-0.4.6-9gqoIpeYmGjDLnucKUpqef
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-req/html/req.haddock
haddock-html:         /usr/share/doc/haskell-req/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
